@@ -7,6 +7,13 @@ import logging
 from collections import OrderedDict
 from wadltools.wadl import WADL, DocHelper
 
+class WADLParseError(Exception):
+    def __init__(self, message, wadl_file, location, cause):
+        super(WADLParseError, self).__init__(message + u' in ' + wadl_file + u' ("' + location + '"), caused by ' + repr(cause))
+        self.wadl_file = wadl_file
+        self.location = location
+        self.cause = cause
+
 def merge_dicts(a, b, path=None):
     if path is None: path = []
     for key in b:
@@ -25,11 +32,15 @@ class SwaggerConverter:
     def __init__(self, options):
         self.options = options
         self.autofix = options.autofix
+        self.strict = options.strict
         self.merge_dir = options.merge_dir
 
     def convert(self, title, wadl_file, swagger_file):
         self.logger = logging.getLogger(wadl_file)
         self.logger.info("Converting: %s to %s", wadl_file, swagger_file)
+
+        defaults = self.default_swagger_dict(swagger_file)
+
         wadl = WADL.application_for(wadl_file)
         if self.autofix and wadl.resource_base is None:
             self.logger.warn("Autofix: No base path, setting to http://localhost")
@@ -38,13 +49,19 @@ class SwaggerConverter:
         swagger = OrderedDict()
         swagger['swagger'] = 2
         swagger['info'] = OrderedDict()
-        swagger['info']['title'] = title
-        swagger['info']['version'] = "Unknown"
+        try:
+            swagger['info'] = defaults['info']
+        except KeyError:
+            swagger['info']['title'] = title
+            swagger['info']['version'] = "Unknown"
+        try:
+            swagger['consumes'] = defaults['consumes']
+            swagger['produces'] = defaults['produces']
+        except KeyError:
+            swagger["consumes"] = ["application/json"]
+            swagger["produces"] = ["application/json"]
+
         swagger['paths'] = OrderedDict()
-        swagger["consumes"] = [
-          # default consumes, maybe it shouldn't be hardcoded?
-          "application/json"
-        ]
 
         for resource_element in wadl.resources:
             path = resource_element.attrib['path']
@@ -117,20 +134,25 @@ class SwaggerConverter:
                                 try:
                                     json.loads(code_sample)
                                 except ValueError:
-                                    # sometimes the headers are in the same sample
-                                    # strip them and check again
-                                    match = re.match(r'.*^([\{\[].*)\Z', code_sample, (re.MULTILINE | re.DOTALL))
-                                    if match:
-                                        code_sample = match.group(1)
-                                        json.loads(code_sample)
+                                    if self.autofix:
+                                        # sometimes the headers are in the same sample
+                                        # strip them and check again
+                                        match = re.match(r'.*^([\{\[].*)\Z', code_sample, (re.MULTILINE | re.DOTALL))
+                                        if match:
+                                            code_sample = match.group(1)
+                                            json.loads(code_sample)
                                     else:
-                                        code_sample = None
-                            except ValueError:
-                                logging.warn("Code sample found but cannot be parsed for %s" % swagger_method['summary'])
-                                code_sample = None
+                                        raise
+                            except ValueError as e:
+                                error = WADLParseError("Unparsable code sample", wadl_file, swagger_method['summary'], e)
+                                if self.strict:
+                                    raise error
+                                else:
+                                    self.logger.error(str(error))
+
                         if code_sample:
                             swagger_method['responses'][int(status)]['examples'] = self.build_code_sample(code_sample)
-        swagger = merge_dicts(swagger, self.default_swagger_dict(swagger_file))
+        swagger = merge_dicts(swagger, defaults)
         return swagger
 
     def default_swagger_dict(self, swagger_file):
